# see-saw: For seeing errors and sawing logs

## Usage

1. Export credentials into your shell, using either `AWS_DEFAULT_PROFILE` or the `AWS_*` key variables.
2. Run `seesaw`
3. Navigate with arrow keys, select a region and one or more log groups to query
4. Press `r` to refresh the log viewer
